Utils
-----

.. module:: diofant.geometry.util

.. autofunction:: idiff

.. autofunction:: intersection

.. autofunction:: convex_hull

.. autofunction:: are_similar

.. autofunction:: centroid

.. automodule:: diofant.geometry.exceptions
    :members:
